import { CloudObject, CloudUser } from './ncloud';

// 创建测试用户（如果不存在）
async function createTestUser() {
  const user = new CloudUser();
  const existingUser = await user.login('fitnesstest@example.com', 'test1234');

  if (!existingUser) {
    await user.signUp(
      'fitnesstest@example.com',
      'test1234',
      {
        email: 'fitnesstest@example.com',
        name: '健身测试用户'
      }
    );
    console.log('测试用户创建成功');
  } else {
    console.log('测试用户已存在');
  }
  return user;
}

// 创建减脂训练计划
async function createFatLossPlan(user: CloudUser) {
  const plan = new CloudObject('TrainingPlan');

  plan.set({
    planName: '4周高效减脂计划',
    description: '针对初学者的科学减脂训练方案，结合有氧和力量训练',
    durationInWeeks: 4,
    difficultyLevel: '初级',
    fitnessGoals: ['减脂', '提高耐力', '基础力量'],
    schedule: {
      monday: true,
      wednesday: true,
      friday: true,
      saturday: true
    },
    user: user.toPointer(),
    tags: ['减脂', '新手友好', '家庭训练'],
    isPublic: true
  });

  await plan.save();
  console.log('训练计划创建成功:', plan.id);
  return plan;
}

// 创建减脂训练任务
async function createFatLossTasks(plan: CloudObject) {
  const tasks = [
    {
      taskName: '热身 - 动态拉伸',
      description: '5分钟全身动态拉伸，提高心率',
      taskType: '热身',
      estimatedDuration: 5,
      isCompleted: false,
      orderNumber: 1,
      targetMetrics: {
        heartRate: '100-120bpm'
      }
    },
    {
      taskName: '高强度间歇训练(HIIT)',
      description: '20秒高强度运动+40秒休息，重复8组',
      taskType: '有氧',
      estimatedDuration: 15,
      isCompleted: false,
      orderNumber: 2,
      targetMetrics: {
        heartRate: '140-160bpm',
        calories: '150-200kcal'
      }
    },
    {
      taskName: '全身循环训练',
      description: '深蹲+俯卧撑+平板支撑，每个动作45秒，休息15秒，3轮',
      taskType: '力量',
      estimatedDuration: 20,
      isCompleted: false,
      orderNumber: 3,
      targetMetrics: {
        reps: '12-15/组'
      }
    },
    {
      taskName: '核心训练',
      description: '仰卧卷腹+俄罗斯转体+平板支撑，每个动作30秒',
      taskType: '核心',
      estimatedDuration: 10,
      isCompleted: false,
      orderNumber: 4,
      targetMetrics: {
        sets: '3组'
      }
    },
    {
      taskName: '放松拉伸',
      description: '10分钟静态拉伸，重点下肢',
      taskType: '恢复',
      estimatedDuration: 10,
      isCompleted: false,
      orderNumber: 5,
      targetMetrics: {
        duration: '每个部位30秒'
      }
    }
  ];

  for (const taskData of tasks) {
    const task = new CloudObject('TrainingTask');
    task.set({
      ...taskData,
      plan: plan.toPointer()
    });
    await task.save();
    console.log(`任务创建成功: ${taskData.taskName}`);
  }
}

// 主执行函数
export async function importFatLossTrainingData() {
  try {
    console.log('开始导入减脂训练测试数据...');

    // 1. 创建/获取测试用户
    const user = await createTestUser();

    // 2. 创建训练计划
    const plan = await createFatLossPlan(user);

    // 3. 创建训练任务
    await createFatLossTasks(plan);

    console.log('减脂训练测试数据导入完成！');
  } catch (error) {
    console.error('导入数据时出错:', error);
  }
}




// 创建增肌测试用户（如果不存在）
async function createMuscleGainUser() {
  const user = new CloudUser();
  const existingUser = await user.login('muscletest@example.com', 'gain1234');

  if (!existingUser) {
    await user.signUp(
      'muscletest@example.com',
      'gain1234',
      {
        email: 'muscletest@example.com',
        name: '增肌测试用户',
        bodyWeight: 70,  // 公斤
        height: 175      // 厘米
      }
    );
    console.log('增肌测试用户创建成功');
  } else {
    console.log('增肌测试用户已存在');
  }
  return user;
}

// 创建增肌训练计划
async function createMuscleGainPlan(user: CloudUser) {
  const plan = new CloudObject('TrainingPlan');

  plan.set({
    planName: '6周科学增肌计划',
    description: '针对中级训练者的肌肉增长方案，采用分化训练',
    durationInWeeks: 6,
    difficultyLevel: '中级',
    fitnessGoals: ['增肌', '力量提升', '肌肥大'],
    schedule: {
      monday: '胸+三头',
      tuesday: '背+二头',
      wednesday: '休息',
      thursday: '腿',
      friday: '肩+腹',
      saturday: '全身功能性',
      sunday: '休息'
    },
    userId: user.toPointer(),
    tags: ['增肌', '分化训练', '健身房'],
    isPublic: true,
    recommendedNutrition: {
      protein: '2g/kg体重',
      carbs: '4g/kg体重',
      fats: '1g/kg体重'
    }
  });

  await plan.save();
  console.log('增肌训练计划创建成功:', plan.id);
  return plan;
}

// 创建增肌训练任务（按训练日分组）
async function createMuscleGainTasks(plan: CloudObject) {
  // 周一：胸+三头
  await createTrainingDayTasks(plan, '胸+三头', 1, [
    {
      taskName: '平板杠铃卧推',
      description: '4组×8-12次，组间休息90秒',
      taskType: '力量',
      estimatedDuration: 15,
      targetMetrics: {
        weight: '渐进超负荷',
        rpe: '7-8'
      }
    },
    {
      taskName: '上斜哑铃卧推',
      description: '3组×10-12次',
      taskType: '力量',
      estimatedDuration: 10,
      targetMetrics: {
        rpe: '7-8'
      }
    },
    {
      taskName: '双杠臂屈伸（负重）',
      description: '3组×最大次数',
      taskType: '力量',
      estimatedDuration: 10,
      targetMetrics: {
        addedWeight: '5-10kg'
      }
    },
    {
      taskName: '绳索下压',
      description: '4组×12-15次，递减组',
      taskType: '力量',
      estimatedDuration: 12,
      targetMetrics: {
        technique: '顶峰收缩2秒'
      }
    }
  ]);

  // 周二：背+二头
  await createTrainingDayTasks(plan, '背+二头', 2, [
    {
      taskName: '引体向上',
      description: '4组×力竭，可辅助',
      taskType: '力量',
      estimatedDuration: 12,
      targetMetrics: {
        reps: '每组8+'
      }
    },
    {
      taskName: '杠铃划船',
      description: '4组×8-12次，严格姿势',
      taskType: '力量',
      estimatedDuration: 15,
      targetMetrics: {
        weight: '渐进超负荷'
      }
    },
    {
      taskName: '哑铃单臂划船',
      description: '3组×10-12次/侧',
      taskType: '力量',
      estimatedDuration: 10,
      targetMetrics: {
        mindMuscle: '强调背肌收缩'
      }
    },
    {
      taskName: '杠铃弯举',
      description: '21响礼炮（7次下半程+7次上半程+7次全程）',
      taskType: '力量',
      estimatedDuration: 10,
      targetMetrics: {
        technique: '控制离心'
      }
    }
  ]);

  // 周四：腿
  await createTrainingDayTasks(plan, '腿', 3, [
    {
      taskName: '深蹲',
      description: '5组×5次，大重量',
      taskType: '力量',
      estimatedDuration: 20,
      targetMetrics: {
        weight: '85% 1RM'
      }
    },
    {
      taskName: '罗马尼亚硬拉',
      description: '4组×8次',
      taskType: '力量',
      estimatedDuration: 15,
      targetMetrics: {
        stretch: '强调腘绳肌拉伸'
      }
    },
    {
      taskName: '腿举',
      description: '3组×12-15次，递减组',
      taskType: '力量',
      estimatedDuration: 12,
      targetMetrics: {
        footPosition: '不同站距'
      }
    },
    {
      taskName: '坐姿提踵',
      description: '4组×15-20次',
      taskType: '力量',
      estimatedDuration: 8,
      targetMetrics: {
        range: '全程动作'
      }
    }
  ]);

  // 周五：肩+腹
  await createTrainingDayTasks(plan, '肩+腹', 4, [
    {
      taskName: '站姿杠铃推举',
      description: '4组×6-8次',
      taskType: '力量',
      estimatedDuration: 12,
      targetMetrics: {
        strictForm: '避免借力'
      }
    },
    {
      taskName: '哑铃侧平举',
      description: '5组×12-15次，渐降组',
      taskType: '力量',
      estimatedDuration: 15,
      targetMetrics: {
        weight: '递减重量'
      }
    },
    {
      taskName: '面拉',
      description: '4组×15次',
      taskType: '力量',
      estimatedDuration: 10,
      targetMetrics: {
        focus: '后束激活'
      }
    },
    {
      taskName: '悬挂举腿',
      description: '4组×12次',
      taskType: '核心',
      estimatedDuration: 8,
      targetMetrics: {
        control: '避免摆动'
      }
    }
  ]);

  // 周六：全身功能性
  await createTrainingDayTasks(plan, '全身功能性', 5, [
    {
      taskName: '农夫行走',
      description: '3组×30秒',
      taskType: '功能性',
      estimatedDuration: 10,
      targetMetrics: {
        weight: '挑战性重量'
      }
    },
    {
      taskName: '药球砸地',
      description: '4组×15次',
      taskType: '爆发力',
      estimatedDuration: 8,
      targetMetrics: {
        power: '最大爆发'
      }
    },
    {
      taskName: '战绳训练',
      description: '30秒全力+30秒休息，5轮',
      taskType: '心肺',
      estimatedDuration: 10,
      targetMetrics: {
        intensity: '全力输出'
      }
    }
  ]);
}

// 辅助函数：为特定训练日创建任务
async function createTrainingDayTasks(plan: CloudObject, dayName: string, dayOrder: number, tasks: any[]) {
  for (const [index, taskData] of tasks.entries()) {
    const task = new CloudObject('TrainingTask');
    task.set({
      ...taskData,
      planId: plan.toPointer(),
      orderNumber: dayOrder * 100 + index + 1, // 确保排序正确
      trainingDay: dayName,
      isCompleted: false
    });
    await task.save();
    console.log(`[${dayName}] 任务创建成功: ${taskData.taskName}`);
  }
}

// 主执行函数
export async function importMuscleGainTrainingData() {
  try {
    console.log('开始导入增肌训练测试数据...');

    // 1. 创建/获取测试用户
    const user = await createMuscleGainUser();

    // 2. 创建训练计划
    const plan = await createMuscleGainPlan(user);

    // 3. 创建训练任务（按训练日分组）
    await createMuscleGainTasks(plan);

    console.log('增肌训练测试数据导入完成！');
  } catch (error) {
    console.error('导入数据时出错:', error);
  }
}
